/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import React, {useMemo} from 'react';

import APIFormBase from './APIFormBase';
import {useAppState} from './hooks/appState';
import {getBaseURL, getCategoryURL} from './util/url';
import {getSchemaType} from './util/util';

const getContentType = (requestBody) =>
	requestBody
		? requestBody.content['multipart/form-data']
			? 'multipart/form-data'
			: requestBody.content['application/json']
			? 'application/json'
			: null
		: null;

const APIForm = (_) => {
	const [state, dispatch] = useAppState();

	const {
		categories,
		categoryKey,
		headers,
		method,
		path,
		paths,
		schemas,
	} = state;

	const methodData = paths[path][method];

	const {operationId, requestBody} = methodData;

	const schema = schemas[getSchemaType(requestBody)];

	const baseURL = getBaseURL(getCategoryURL(categories, categoryKey));

	const contentType = useMemo(() => getContentType(requestBody), [
		requestBody,
	]);

	return (
		<APIFormBase
			baseURL={baseURL}
			contentType={contentType}
			headers={headers}
			key={operationId}
			method={method}
			methodData={methodData}
			onResponse={({apiURL, data, response}) => {
				dispatch({
					apiURL,
					contentType,
					data,
					response,
					type: 'LOAD_API_RESPONSE',
				});
			}}
			path={path}
			schema={schema}
		/>
	);
};

export default APIForm;
