/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import React, {useEffect, useRef} from 'react';

const PathList = (props) => {
	const {curPath, filter, onClick, paths} = props;

	const selectedPathEl = useRef(null);

	useEffect(() => {
		if (selectedPathEl && selectedPathEl.current) {
			selectedPathEl.current.scrollIntoView();

			window.scroll(0, 0);
		}
	}, []);

	let pathKeys = Object.keys(paths).sort();

	if (filter.trim().length > 0) {
		pathKeys = pathKeys.filter((pathkey) =>
			pathkey.toLowerCase().includes(filter.toLowerCase())
		);
	}

	return (
		<>
			{pathKeys.map((path) => (
				<button
					className={`btn btn-block ${
						path === curPath ? 'btn-primary' : 'btn-secondary'
					} mb-3 text-left`}
					key={path}
					onClick={() => onClick(path)}
					ref={path === curPath ? selectedPathEl : null}
					type="button"
				>
					{path}
				</button>
			))}
		</>
	);
};

export default PathList;
