/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import ClayForm, {ClayInput} from '@clayui/form';
import {connect, getIn} from 'formik';
import React from 'react';

import Icon from '../Icon';
import CFErrorMessage from './CFErrorMessage';

const CFInput = (props) => {
	const {component, formik, name, required, type, ...otherProps} = props;

	const {errors, handleBlur, handleChange, touched, values} = formik;

	const error = getIn(errors, name);
	const touch = getIn(touched, name);

	return (
		<ClayForm.Group
			className={error && touch ? 'has-error' : ''}
			key={name}
		>
			<label htmlFor={name}>
				{name}
				{!!required && (
					<Icon className="reference-mark" symbol="asterisk" />
				)}
			</label>

			<ClayInput.Group>
				<ClayInput.GroupItem prepend>
					<ClayInput
						component={component}
						name={name}
						onBlur={handleBlur}
						onChange={handleChange}
						type="text"
						value={values[name]}
						{...otherProps}
					/>
				</ClayInput.GroupItem>
				<ClayInput.GroupItem append shrink>
					<ClayInput.GroupText className="h-100">
						{type}
					</ClayInput.GroupText>
				</ClayInput.GroupItem>
			</ClayInput.Group>

			<CFErrorMessage name={name} />
		</ClayForm.Group>
	);
};

export default connect(CFInput);
