/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

export const getCategoryURL = (categories, categoryKey) => {
	return categories && categoryKey && categories
		? categories[categoryKey][0]
		: '';
};

export const getBaseURL = (categoryURL) => {
	return categoryURL.replace('/v1.0/openapi.json', '');
};

export const getSearchParams = (params = [], values) => {
	var searchParams = new URLSearchParams();

	params.forEach((param) => {
		const value = values[param.name];

		if (param.in === 'query' && value) {
			searchParams.set(param.name, value);
		}
	});

	const paramsString = searchParams.toString();

	return paramsString.length > 0 ? `?${searchParams.toString()}` : '';
};

export const getURL = ({baseURL, params, path, values}) => {
	return (
		baseURL +
		replaceParams(path, params, values) +
		getSearchParams(params, values)
	);
};

export const replaceParams = (path, params, values) => {
	if (params) {
		params.forEach((param) => {
			if (param.in === 'path') {
				path = path.replace(`{${param.name}}`, values[param.name]);
			}
		});
	}

	return path;
};
